@@ -1,11 +1,6 @@
 from PyObjCTools.TestSupport import *
 from SystemConfiguration import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestSCSchemaDefinitions (TestCase):
     @min_os_level('10.5')
     def testConstants10_5(self):
@@ -37,6 +32,10 @@ class TestSCSchemaDefinitions (TestCase):
         self.assertIsInstance(kSCValNetSMBNetBIOSNodeTypeMixed, unicode)
         self.assertIsInstance(kSCValNetSMBNetBIOSNodeTypeHybrid, unicode)
 
+    @min_os_level('10.6')
+    def testConstants10_5_missing(self):
+        self.assertIsInstance(kSCValNetIPSecAuthenticationMethodHybrid, unicode)
+
     def testConstants(self):
         self.assertIsInstance(kSCResvLink, unicode)
         self.assertIsInstance(kSCResvInactive, unicode)
@@ -287,6 +286,20 @@ class TestSCSchemaDefinitions (TestCase):
         self.assertIsInstance(kSCPropUsersConsoleUserUID, unicode)
         self.assertIsInstance(kSCPropUsersConsoleUserGID, unicode)
 
+    @min_os_level('10.6')
+    def testConstants10_6(self):
+        self.assertIsInstance(kSCValNetInterfaceTypeIPSec, unicode)
+        self.assertIsInstance(kSCPropNetIPSecConnectTime, unicode)
+        self.assertIsInstance(kSCPropNetIPSecRemoteAddress, unicode)
+        self.assertIsInstance(kSCPropNetIPSecStatus, unicode)
+        self.assertIsInstance(kSCPropNetIPSecXAuthEnabled, unicode)
+        self.assertIsInstance(kSCPropNetIPSecXAuthName, unicode)
+        self.assertIsInstance(kSCPropNetIPSecXAuthPassword, unicode)
+        self.assertIsInstance(kSCPropNetIPSecXAuthPasswordEncryption, unicode)
+        self.assertIsInstance(kSCValNetIPSecXAuthPasswordEncryptionKeychain, unicode)
+        self.assertIsInstance(kSCValNetIPSecXAuthPasswordEncryptionPrompt, unicode)
+        self.assertIsInstance(kSCValNetIPv4ConfigMethodAutomatic, unicode)
+
     @min_os_level('10.7')
     def testConstants10_7(self):
         self.assertIsInstance(kSCValNetIPv6ConfigMethodLinkLocal, unicode)
